@@ -371,17 +371,8 @@ open_cb(BonoboUIComponent *uic, gpointer user_data, const gchar* verbname)
 
 	win = GHEX_WINDOW(user_data);
 
-	if(win->gh)
-		doc = win->gh->document;
-	else
-		doc = NULL;
-
 	file_sel = gtk_file_selection_new(NULL);
 
-	if(doc)
-		gtk_file_selection_set_filename(GTK_FILE_SELECTION(file_sel),
-										doc->file_name);
-
 	gtk_window_set_title(GTK_WINDOW(file_sel), _("Select a file to open"));
 	
 	gtk_signal_connect (GTK_OBJECT (GTK_FILE_SELECTION (file_sel)->ok_button),
@@ -760,7 +751,6 @@ ghex_print(GtkHex *gh, gboolean preview)
 
 	ghex_print_update_page_size_and_margins (doc, pji);
 	ghex_print_job_execute(pji);
-	gnome_print_job_close (pji->master);
 
 	if (pji->preview)
 		ghex_print_preview_real(pji);
@@ -875,7 +865,7 @@ display_info_dialog (GHexWindow *win, const gchar *msg, ...)
 	g_return_if_fail (msg != NULL);
 	va_start(args, msg);
 	real_msg = g_strdup_vprintf(msg, args);
-	va_end(msg);
+	va_end(args);
 	info_dlg = gtk_message_dialog_new (
 			GTK_WINDOW (win),
 			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
